@@ -17,16 +17,25 @@ from mercurial.i18n import _
 from mercurial.hgweb.common import HTTP_OK
 from mercurial.hgweb.protocol import HGTYPE
 from mercurial.__version__ import version as mercurial_version
-if map(int, mercurial_version.split('.')) >= [1, 6]:
+
+try:
+    test = map(int, mercurial_version.split('.', 2)[:2]) >= [1, 6]
+except ValueError:
+    test = True
+if test:
     from mercurial.hg import remoteui
 else:
     from mercurial.cmdutil import remoteui
-if map(int, mercurial_version.split('.')) >= [1, 7]:
+try:
+    test = map(int, mercurial_version.split('.', 2)[:2]) >= [1, 7]
+except ValueError:
+    test = True
+if test:
     from mercurial import wireproto
 else:
     wireproto = None
 
-__version__ = '0.3'
+__version__ = '0.4'
 
 _nested_cache = {}
 _nested_refreshinterval = 20
@@ -195,6 +204,12 @@ def nclone(ui, source, dest=None, **opts):
         commands.clone(ui, nsource, dest=ndest, **opts)
         ui.status('\n')
 
+def nincoming(ui, repo, dest=None, **opts):
+    '''show changest not found in repository and all nested repositories
+
+    Look at the help of incoming command for more informations.'''
+    _nested_apply(ui, repo, commands.incoming, True, dest=dest, **opts)
+
 def noutgoing(ui, repo, dest=None, **opts):
     '''show changesest not found in the destination and all nested repositories
 
@@ -284,6 +299,9 @@ cmdtable = {
     '^nclone': (nclone,
         cmdutil.findcmd('clone', commands.table)[1][1],
         _('[OPTION]... SOURCE [DEST]')),
+    'nincoming|nin': (nincoming,
+        cmdutil.findcmd('incoming', commands.table)[1][1],
+        _('[-p] [-n] [-M] [-f] [-r REV]... [--bundle FILENAME] [SOURCE]')),
     'noutgoing|nout': (noutgoing,
         cmdutil.findcmd('outgoing', commands.table)[1][1],
         _('[-M] [-p] [-n] [-f] [-r REV]... [DEST]')),
